import base64
from cryptography.fernet import Fernet
from core.config import settings


# Ensure the secret key is 32 bytes and Base64 encoded
def get_fernet_key(secret_key: str) -> bytes:
    """Convert a plain string secret key to a valid Fernet key."""
    key_bytes = secret_key.encode()  # Convert to bytes
    padded_key = base64.urlsafe_b64encode(key_bytes.ljust(32)[:32])  # Ensure 32 bytes
    return padded_key


# Convert settings.secret_key to a valid Fernet key
SECRET_KEY = get_fernet_key(settings.secret_key)

# Initialize the Fernet encryption object
fernet = Fernet(SECRET_KEY)


def encrypt_card_number(card_number: str) -> str:
    """Encrypts the card number."""
    return fernet.encrypt(card_number.encode()).decode()


def decrypt_card_number(encrypted_card: str) -> str:
    """Decrypts the encrypted card number."""
    return fernet.decrypt(encrypted_card.encode()).decode()
