import customtkinter as ctk
from components.auth.login import login_frame
from components.auth.register import register_frame
from components.shop.create_shop import create_shop_frame
from components.shop.view_shop import view_shop_frame
from components.product.create_product import create_product_frame
from components.product.view_product import view_product_frame
from components.admin.category import category_frame
from components.dashboard import dashboard_frame
from components.user_details import user_details_frame
from components.user_orders import user_orders_frame
from components.user_payments import user_payments_frame

API_URL = "http://127.0.0.1:8000"
access_token = None  # Global token


def switch_frame(frame_name, *args):
    """
    Switch between frames.
    Optionally, additional data (like shop_data) can be passed as extra arguments.
    """
    global access_token
    if args and args[0] and isinstance(args[0], str):
        access_token = args[0]
        # Update token for all frames that need it
        for frame_key in ["dashboard", "user_details", "user_orders", "user_payments", "create_shop", "view_shop", "product", "category"]:
            if frame_key in frames and hasattr(frames[frame_key], "update_token"):
                frames[frame_key].update_token(access_token)

    frame = frames.get(frame_name)
    if frame is None:
        print(f"Frame {frame_name} not found!")
        return

    if hasattr(frame, "refresh_data") and len(args) > 0:
        frame.refresh_data(*args)

    frame.tkraise()


ctk.set_appearance_mode("dark")
ctk.set_default_color_theme("blue")

root = ctk.CTk()
root.title("Shopping App")
root.geometry("1000x800")

# Create Frames with the token parameter where needed.
login = login_frame(root, switch_frame, API_URL)
register = register_frame(root, switch_frame, API_URL)
create_shop = create_shop_frame(
    root, switch_frame, API_URL, access_token
)  # Accepts token
# Fix the parameter order for view_shop_frame
view_shop = view_shop_frame(root, switch_frame, API_URL, access_token, None)  # Pass shop_id as None initially
product = create_product_frame(root, switch_frame, API_URL, access_token)
view_product = view_product_frame(root, switch_frame, API_URL, access_token, None)
category = category_frame(root, switch_frame, API_URL, access_token)
dashboard = dashboard_frame(root, switch_frame, API_URL, access_token)
user_details = user_details_frame(root, switch_frame, API_URL, access_token)
user_orders = user_orders_frame(root, switch_frame, API_URL, access_token)
user_payments = user_payments_frame(root, switch_frame, API_URL, access_token)

frames = {
    "login": login,
    "register": register,
    "create_shop": create_shop,
    "create_product": product,
    "view_product": view_product,
    "category": category,
    "view_shop": view_shop,
    "dashboard": dashboard,
    "user_details": user_details,
    "user_orders": user_orders,
    "user_payments": user_payments,
}

for frame in frames.values():
    frame.place(relx=0, rely=0, relwidth=1, relheight=1)

switch_frame("login")
root.mainloop()
